🔨 Development - ngff-zarr
Description: Contributions are welcome and appreciated! We are glad you are here and appreciate your contribution. Please keep in mind our community participation guidelines. Get the source code: Install depend...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# 🔨 Development

Contributions are welcome and appreciated!

We are glad you are here and appreciate your contribution. Please keep in mind our community participation guidelines.

## Get the source code

    git clone https://github.com/thewtex/ngff-zarr
    cd ngff-zarr

## Install dependencies

First install pixi. Then, install project dependencies:

    pixi install -a
    pixi run pre-commit-install

## Run the test suite

    pixi run test

## Build the documentation

If needed, build and update the documentation:

    pixi run dev-docs

## Update test data

If needed, update the testing data.

1. Generate new test data tarball and compute its sha256 hash

    pixi run hash-data

2. Upload the data to web3.storage

3. Upload the `test_data_ipfs_cid` (from web3.storage web UI) and `test_data_sha256` (`sh256sum ../data.tar.gz`) variables in test/_data.py.

## Submit the patch

We use the standard GitHub flow.